/*
 * @(#)RDFTuple.java   1.0   02/ott/2009
 *
 * Copyright 2009-2009 Politecnico di Milano. All Rights Reserved.
 *
 * This software is the proprietary information of Politecnico di Milano.
 * Use is subject to license terms.
 *
 * @(#) $Id$
 */
package eu.larkc.csparql.common;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class RDFTable implements Collection<RDFTuple> {

	private final List<String> names = new ArrayList<String>();
	private final List<RDFTuple> tuples = new ArrayList<RDFTuple>();

	public boolean isGraph() {
		// TODO: fix this fake implementation
		return true;
	}

	public RDFTable(final String... fieldsNames) {

		for (final String fn : fieldsNames) {
			this.names.add(fn);
		}

	}

	public RDFTable(final List<String> fieldsNames) {

		for (final String fn : fieldsNames) {
			this.names.add(fn);
		}
	}

	public void add(final String fieldName, final String fieldDefaultValue) {
		names.add(fieldName);
		for (RDFTuple t : tuples) {
			t.addFields(fieldDefaultValue);
		}
	}

	public void add(final Iterable<RDFTuple> tuplesToAdd) {
		for (final RDFTuple tta : tuplesToAdd) {
			this.add(tta);
		}
	}

	public boolean add(final RDFTuple tupleToAdd) {
		return this.getTuples().add(tupleToAdd);
	}

	public int size() {
		return this.getTuples().size();
	}

	@Override
	public String toString() {
		StringBuffer sb = new StringBuffer();

		for (final String n : this.names) {
			sb = sb.append(n).append("\t");
		}

		sb.append("\n");

		for (final RDFTuple t : this.getTuples()) {
			sb = sb.append(t.toString()).append("\n");
		}

		return sb.toString();
	}

	@Override
	public boolean addAll(final Collection<? extends RDFTuple> arg0) {
		return this.getTuples().addAll(arg0);
	}

	@Override
	public void clear() {
		this.getTuples().clear();
	}

	@Override
	public boolean contains(final Object arg0) {
		return this.getTuples().contains(arg0);
	}

	@Override
	public boolean containsAll(final Collection<?> arg0) {
		return this.getTuples().containsAll(arg0);
	}

	@Override
	public boolean isEmpty() {
		return this.getTuples().isEmpty();
	}

	@Override
	public Iterator<RDFTuple> iterator() {
		return this.getTuples().iterator();
	}

	@Override
	public boolean remove(final Object arg0) {
		return this.getTuples().remove(arg0);
	}

	@Override
	public boolean removeAll(final Collection<?> arg0) {
		return this.getTuples().removeAll(arg0);
	}

	@Override
	public boolean retainAll(final Collection<?> arg0) {
		return this.getTuples().retainAll(arg0);
	}

	@Override
	public Object[] toArray() {
		return this.getTuples().toArray();
	}

	@Override
	public <T> T[] toArray(final T[] arg0) {
		return this.getTuples().toArray(arg0);
	}

	public Collection<RDFTuple> getTuples() {
		return tuples;
	}

	public Collection<String> getNames() {
		return names;
	}
}
